﻿using System;
using System.Collections.Generic;

using NUnit.Framework;

using Yawf.Core;
using Yawf.Test;

namespace Yawf.Data {
	[TestFixture]
	public class IbatisPersisterTest {
		private IbatisPersister persister;

		[SetUp]
		public virtual void SetUp() {
			persister = Initializer.Instance.GetObject("ibatisPersister") as IbatisPersister;
		}
		[Test]
		public void TestFindOne() {
			DummyClass o;

			Assert.IsNotNull(persister,"persister is null");
			o = persister.FindOne<DummyClass>("getDummyById",Int32.Parse("5"));
			Assert.IsNotNull(o,"object returned by FindOne is null");
			Assert.IsInstanceOfType(typeof(DummyClass),o,"Object returned by FindOne is ont a DummyClass");
			Assert.IsTrue(o.Id == 5,"ID != null");
		}								// TestFindOne

		[Test]
		public void TestFindList() {
			IList<DummyClass> hits;

			hits = persister.FindList<DummyClass>("getDummies",null);
			Assert.IsNotNull(hits,"hits returned by FindList is null");
			Assert.IsTrue(hits.Count > 0,"hits.Count returned by FindList <= 0");

			hits = persister.FindList<DummyClass>("getDummies");
			Assert.IsNotNull(hits,"hits returned by FindList is null");
			Assert.IsTrue(hits.Count > 0,"hits.Count returned by FindList <= 0");

			hits = persister.FindList<DummyClass>("getDummies",null,1,3);
			Assert.IsNotNull(hits,"hits returned by FindList is null");
			Assert.IsTrue(hits.Count == 3,"hits.Count returned by FindList != 3");
		}

		[Test]
		public void TestInsertUpdateDelete() {
			DummyClass dummyInserted,tmpDummy;

			dummyInserted = new DummyClass();
			dummyInserted.Value1 = 9999;
			dummyInserted.Value2 = 99;
			dummyInserted.Value3 = 99.99M;
			dummyInserted.Value4 = "Nueve Nueve";
			Assert.AreEqual(0,dummyInserted.Id,"Id != 0");
			persister.Insert("insertDummy",dummyInserted);

			Assert.IsTrue(dummyInserted.Id > 0,"dummyInserted.Id <= 0 After insert");

			tmpDummy = persister.FindOne<DummyClass>("getDummyById",dummyInserted.Id);
			Assert.IsNotNull(tmpDummy,"Dummy class was not inserted");
			Assert.AreEqual(dummyInserted.Id,tmpDummy.Id,"Inserted id != to loaded Id");
			Assert.AreEqual(dummyInserted.Value1,9999,"Value1 was not saved with 9999");
			Assert.AreEqual(dummyInserted.Value2,99,"Value2 was not saved with 99");
			Assert.AreEqual(dummyInserted.Value3,99.99M,"Value3 was not saved with 99.99");
			Assert.AreEqual(dummyInserted.Value4,"Nueve Nueve","Value4 was not saved with 'Nueve Nueve'");

			dummyInserted.Value1 = 19999;
			dummyInserted.Value2 = 199;
			dummyInserted.Value3 = 199.99M;
			dummyInserted.Value4 = "Uno Nueve Nueve";
			persister.Update("updateDummy",dummyInserted);
			tmpDummy = persister.FindOne<DummyClass>("getDummyById",dummyInserted.Id);
			Assert.IsNotNull(tmpDummy,"Dummy class was not updated");
			Assert.AreEqual(dummyInserted.Id,tmpDummy.Id,"Inserted id != to loaded Id");
			Assert.AreEqual(dummyInserted.Value1,19999,"Value1 was not saved with 19999");
			Assert.AreEqual(dummyInserted.Value2,199,"Value2 was not saved with 199");
			Assert.AreEqual(dummyInserted.Value3,199.99,"Value3 was not saved with 199.99");
			Assert.AreEqual(dummyInserted.Value4,"Uno Nueve Nueve","Value4 was not saved with 'Uno Nueve Nueve'");

			persister.Delete("deleteDummy",dummyInserted.Id);
			tmpDummy = persister.FindOne<DummyClass>("getDummyById",dummyInserted.Id);
			Assert.IsNull(tmpDummy,"Dummy class was not deleted");
		}						// TestInsertUpdateDelete
	}
}
